import {
  handleSendTransaction
} from "./chunk-5VZNJ4VT.js";
import {
  DynamicContextProviderWrapper
} from "./chunk-RZT2J42J.js";
import {
  __async,
  __spreadValues
} from "./chunk-CRTRMMJ7.js";

// src/components/embed/v3/crypto/CryptoWalletConnectionHandler.tsx
import {
  chainIdToBlockchain
} from "@crossmint/common-sdk-base";
import { EthereumWalletConnectors } from "@dynamic-labs/ethereum";
import { useDynamicContext } from "@dynamic-labs/sdk-react-core";
import { SolanaWalletConnectors } from "@dynamic-labs/solana";
import { useEffect } from "react";
import { jsx } from "react/jsx-runtime";
function CryptoWalletConnectionHandler(props) {
  const { iframeClient, apiKeyEnvironment } = props;
  return /* @__PURE__ */ jsx(
    DynamicContextProviderWrapper,
    {
      apiKeyEnvironment,
      settings: {
        walletConnectors: [EthereumWalletConnectors, SolanaWalletConnectors],
        events: {
          onAuthFlowCancel() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowCancel");
            iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.failed", {
              error: "cancelled"
            });
          },
          onAuthFlowClose() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowClose");
          },
          onAuthFailure(data, reason) {
            console.error("[CryptoWalletConnectionHandler] onAuthFailure", data, reason);
          },
          onAuthSuccess(data) {
            console.log("[CryptoWalletConnectionHandler] onAuthSuccess", data);
          }
        },
        handlers: {
          handleConnectedWallet: (wallet) => __async(this, null, function* () {
            var _a;
            console.log("[CryptoWalletConnectionHandler] handleConnectedWallet", wallet);
            const address = wallet.address;
            if (!address) {
              console.error("[CryptoWalletConnectionHandler] handleConnectedWallet: address is missing");
              iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.failed", {
                error: "address is missing"
              });
              return false;
            }
            const chain = yield dynamicChainToCrossmintChain(wallet);
            iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.success", {
              address,
              chain,
              walletProviderKey: (_a = wallet.connector) == null ? void 0 : _a.key
            });
            return true;
          })
        }
      },
      children: /* @__PURE__ */ jsx(_CryptoWalletConnectionHandler, __spreadValues({}, props))
    }
  );
}
function _CryptoWalletConnectionHandler({ iframeClient }) {
  const { setShowAuthFlow, primaryWallet, handleLogOut } = useDynamicContext();
  useEffect(() => {
    if (iframeClient == null) {
      return;
    }
    const showAuthFlowListener = iframeClient.on("crypto:connect-wallet.show", (_0) => __async(this, [_0], function* ({ show }) {
      yield handleLogOut();
      setShowAuthFlow(show);
    }));
    return () => {
      iframeClient.off(showAuthFlowListener);
    };
  }, [iframeClient, handleLogOut, setShowAuthFlow]);
  useEffect(() => {
    if (iframeClient == null) {
      return;
    }
    const signTransactionListener = iframeClient.on(
      "crypto:send-transaction",
      (_0) => __async(this, [_0], function* ({ chain, serializedTransaction }) {
        if (primaryWallet == null) {
          console.error("[CryptoWalletConnectionHandler] signTransaction: primaryWallet is missing");
          iframeClient.send("crypto:send-transaction:failed", {
            error: "primaryWallet is missing"
          });
          return;
        }
        yield handleSendTransaction(
          primaryWallet,
          chain,
          serializedTransaction,
          iframeClient
        );
      })
    );
    return () => {
      iframeClient.off(signTransactionListener);
    };
  }, [iframeClient, primaryWallet]);
  return null;
}
function dynamicChainToCrossmintChain(wallet) {
  return __async(this, null, function* () {
    var _a;
    const chain = wallet.chain;
    if (chain === "SOL") {
      return "solana";
    }
    const chainId = yield (_a = wallet.connector) == null ? void 0 : _a.getNetwork();
    if (typeof chainId !== "number") {
      throw new Error("chainId is not a number");
    }
    const chainFromChainId = chainIdToBlockchain(chainId);
    if (!chainFromChainId) {
      throw new Error(`ChainId ${chainId} is not supported`);
    }
    return chainFromChainId;
  });
}

export {
  CryptoWalletConnectionHandler
};
//# sourceMappingURL=chunk-UC3GWTEN.js.map